import { SlideProps } from '@material-ui/core/Slide';
import { Theme } from '@material-ui/core/styles';
import React from 'react';
import { componentType } from '../services';
import { RootReducerType } from '../store';
import { LocalizationStateType } from '../store/Localization';
/**
 * Defined the component's own properties
 */
export interface OwnProps {
    hostName: string;
    documentIdOrPath: string | number;
    version?: string;
    localization?: Partial<LocalizationStateType>;
    drawerSlideProps?: Partial<SlideProps>;
    loaderImage?: string;
    theme?: Theme;
}
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
declare const mapStateToProps: (state: RootReducerType) => {
    isLoading: boolean;
    idOrPath: string | number;
    previewState: number;
    docViewerError: string | undefined;
    previewImagesError: string | null;
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
declare const mapDispatchToProps: {
    pollDocumentData: (hostName: string, idOrPath: string | number, version?: string) => {
        type: string;
        inject: (options: import("redux-di-middleware").IInjectableActionCallbackParams<RootReducerType>) => Promise<void>;
    };
    setLocalization: (localization: Partial<LocalizationStateType>) => {
        type: string;
        localization: Partial<LocalizationStateType>;
    };
};
declare type docViewerComponentType = componentType<typeof mapStateToProps, typeof mapDispatchToProps, OwnProps>;
/**
 * Main document viewer component
 */
export declare class DocumentViewerComponent extends React.Component<docViewerComponentType> {
    constructor(props: docViewerComponentType);
    /** triggered when the component will receive props */
    componentWillReceiveProps(newProps: this['props']): void;
    /**
     * renders the component
     */
    render(): JSX.Element;
}
declare const connectedComponent: import("react-redux").ConnectedComponentClass<typeof DocumentViewerComponent, Pick<componentType<(state: RootReducerType) => {
    isLoading: boolean;
    idOrPath: string | number;
    previewState: number;
    docViewerError: string | undefined;
    previewImagesError: string | null;
}, {
    pollDocumentData: (hostName: string, idOrPath: string | number, version?: string) => {
        type: string;
        inject: (options: import("redux-di-middleware").IInjectableActionCallbackParams<RootReducerType>) => Promise<void>;
    };
    setLocalization: (localization: Partial<LocalizationStateType>) => {
        type: string;
        localization: Partial<LocalizationStateType>;
    };
}, OwnProps, {
    isLoading: boolean;
    idOrPath: string | number;
    previewState: number;
    docViewerError: string | undefined;
    previewImagesError: string | null;
}, RootReducerType>, "version" | "localization" | "drawerSlideProps" | "theme" | "hostName" | "documentIdOrPath" | "loaderImage">>;
export { connectedComponent as DocumentViewer };
//# sourceMappingURL=DocumentViewer.d.ts.map