"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importDefault(require("react"));
const react_redux_1 = require("react-redux");
const styled_components_1 = require("styled-components");
const loader_gif_1 = tslib_1.__importDefault(require("../../assets/loader.gif"));
const models_1 = require("../models");
const store_1 = require("../store");
const Localization_1 = require("../store/Localization");
const DocumentViewerError_1 = require("./DocumentViewerError");
const DocumentViewerLayout_1 = require("./DocumentViewerLayout");
const DocumentViewerLoading_1 = require("./DocumentViewerLoading");
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
const mapStateToProps = (state) => {
    return {
        isLoading: state.sensenetDocumentViewer.documentState.isLoading,
        idOrPath: state.sensenetDocumentViewer.documentState.document &&
            state.sensenetDocumentViewer.documentState.document.idOrPath,
        previewState: state.sensenetDocumentViewer.documentState.document &&
            state.sensenetDocumentViewer.documentState.document.pageCount,
        docViewerError: state.sensenetDocumentViewer.documentState.error,
        previewImagesError: state.sensenetDocumentViewer.previewImages.error,
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
const mapDispatchToProps = {
    pollDocumentData: store_1.pollDocumentData,
    setLocalization: Localization_1.setLocalization,
};
/**
 * Main document viewer component
 */
class DocumentViewerComponent extends react_1.default.Component {
    constructor(props) {
        super(props);
        if (this.props.documentIdOrPath) {
            this.props.pollDocumentData(this.props.hostName, this.props.documentIdOrPath, this.props.version);
        }
        if (this.props.localization) {
            this.props.setLocalization(this.props.localization);
        }
    }
    /** triggered when the component will receive props */
    componentWillReceiveProps(newProps) {
        if (this.props.hostName !== newProps.hostName ||
            this.props.documentIdOrPath !== newProps.documentIdOrPath ||
            this.props.version !== newProps.version) {
            this.props.pollDocumentData(newProps.hostName || this.props.hostName, newProps.documentIdOrPath || this.props.documentIdOrPath, newProps.version || this.props.version);
        }
        if (this.props.localization) {
            this.props.setLocalization(this.props.localization);
        }
    }
    /**
     * renders the component
     */
    render() {
        if (this.props.isLoading) {
            return react_1.default.createElement(DocumentViewerLoading_1.DocumentViewerLoading, { image: this.props.loaderImage || loader_gif_1.default });
        }
        const isPreviewError = this.props.previewState !== -1 && this.props.previewState < 1;
        if (this.props.docViewerError || this.props.previewImagesError || isPreviewError) {
            return react_1.default.createElement(DocumentViewerError_1.DocumentViewerError, { error: this.props.docViewerError || this.props.previewImagesError });
        }
        return (react_1.default.createElement(styled_components_1.ThemeProvider, { theme: this.props.theme || models_1.defaultTheme },
            react_1.default.createElement(DocumentViewerLayout_1.DocumentViewerLayout, { drawerSlideProps: this.props.drawerSlideProps }, this.props.children)));
    }
}
exports.DocumentViewerComponent = DocumentViewerComponent;
const connectedComponent = react_redux_1.connect(mapStateToProps, mapDispatchToProps)(DocumentViewerComponent);
exports.DocumentViewer = connectedComponent;
//# sourceMappingURL=DocumentViewer.js.map