import React = require('react');
import { PreviewState } from '../Enums';
import { componentType } from '../services/TypeHelpers';
import { RootReducerType } from '../store';
/**
 * Defined the component's own properties
 */
export interface OwnProps {
    error: any;
}
/**
 * State type for the Document Viewer Error component
 */
export interface ErrorState {
    message: string;
    details: string;
}
/**
 * Gets the preview state form the document's page count
 * @param {RootReducerType} state
 * @returns {number} page count that can be compared to PreviewState
 */
export declare function getPreviewState(state: RootReducerType): number;
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
declare const mapStateToProps: (state: RootReducerType) => {
    previewState: number;
    errorLoadingDocument: {
        state: PreviewState;
        message: string;
        details: string;
        code?: number | undefined;
    }[];
    errorLoadingDetails: string;
    reloadPage: string;
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
declare const mapDispatchToProps: {};
/**
 * Component to display viewer related errors
 */
export declare class DocumentViewerErrorComponent extends React.Component<componentType<typeof mapStateToProps, typeof mapDispatchToProps, OwnProps>, ErrorState> {
    /**
     * The state object for the Error component
     */
    state: ErrorState;
    /**
     * Returns a derived state from the props
     */
    static getDerivedStateFromProps(props: DocumentViewerErrorComponent['props']): {
        message: string;
        details: string;
    };
    /**
     * renders the component
     */
    render(): JSX.Element;
}
declare const connectedComponent: import("react-redux").ConnectedComponentClass<typeof DocumentViewerErrorComponent, Pick<componentType<(state: RootReducerType) => {
    previewState: number;
    errorLoadingDocument: {
        state: PreviewState;
        message: string;
        details: string;
        code?: number | undefined;
    }[];
    errorLoadingDetails: string;
    reloadPage: string;
}, {}, OwnProps, {
    previewState: number;
    errorLoadingDocument: {
        state: PreviewState;
        message: string;
        details: string;
        code?: number | undefined;
    }[];
    errorLoadingDetails: string;
    reloadPage: string;
}, RootReducerType>, "error">>;
export { connectedComponent as DocumentViewerError };
//# sourceMappingURL=DocumentViewerError.d.ts.map