import { SlideProps } from '@material-ui/core/Slide';
import React = require('react');
import { DraftCommentMarker } from '../models';
import { componentType } from '../services';
import { RootReducerType } from '../store';
import { setSelectedCommentId, toggleIsCreateCommentActive, toggleIsPlacingCommentMarker } from '../store/Comments';
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
declare const mapStateToProps: (state: RootReducerType) => {
    activePages: number[];
    zoomMode: import("../store").ZoomMode;
    customZoomLevel: number;
    showThumbnails: boolean;
    showComments: boolean;
    comments: import("../models").Comment[];
    pageCount: number;
    isCreateCommentActive: boolean;
    isPlacingCommentMarker: boolean;
    selectedCommentId: string;
    fitRelativeZoomLevel: number;
    localization: import("../store/Localization").LocalizationStateType;
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
declare const mapDispatchToProps: {
    setActivePages: (activePages: number[]) => {
        type: string;
        activePages: number[];
    };
    getComments: () => {
        type: string;
        inject: (options: import("redux-di-middleware").IInjectableActionCallbackParams<RootReducerType>) => Promise<void>;
    };
    setThumbnails: (isVisible: boolean) => {
        type: string;
        isVisible: boolean;
    };
    createComment: (comment: Pick<import("../models").Comment, "text" | "page" | "x" | "y">) => {
        type: string;
        inject: (options: import("redux-di-middleware").IInjectableActionCallbackParams<RootReducerType>) => Promise<void>;
    };
    setSelectedCommentId: typeof setSelectedCommentId;
    toggleIsCreateCommentActive: typeof toggleIsCreateCommentActive;
    toggleIsPlacingCommentMarker: typeof toggleIsPlacingCommentMarker;
};
/** Props definition for the Document Viewer layout */
export interface DocumentLayoutOwnProps {
    drawerSlideProps?: Partial<SlideProps>;
}
/** State type definition for the DocumentViewerLayout component */
export interface DocumentLayoutState {
    draftCommentMarker?: DraftCommentMarker;
    activePage?: number;
    thumbnaislVisibility: boolean;
    createCommentValue: string;
}
/**
 * Component for the main DocumentViewer layout
 */
export declare class DocumentViewerLayoutComponent extends React.Component<componentType<typeof mapStateToProps, typeof mapDispatchToProps, DocumentLayoutOwnProps>, DocumentLayoutState> {
    constructor(props: DocumentViewerLayoutComponent['props']);
    private commentsContainerRef;
    componentDidMount(): void;
    componentWillUnmount(): void;
    /** scrolls the viewer to focus to the page with the provided index */
    scrollTo(index: number, smoothScroll?: boolean): void;
    private scrollToImage;
    private handleMarkerCreation;
    private createComment;
    private toggleIsPlacingCommentMarker;
    private handleKeyUp;
    /** triggered when the component will receive props */
    componentWillReceiveProps(newProps: this['props']): void;
    /**
     * renders the component
     */
    render(): JSX.Element;
}
declare const connectedComponent: import("react-redux").ConnectedComponentClass<typeof DocumentViewerLayoutComponent, Pick<componentType<(state: RootReducerType) => {
    activePages: number[];
    zoomMode: import("../store").ZoomMode;
    customZoomLevel: number;
    showThumbnails: boolean;
    showComments: boolean;
    comments: import("../models").Comment[];
    pageCount: number;
    isCreateCommentActive: boolean;
    isPlacingCommentMarker: boolean;
    selectedCommentId: string;
    fitRelativeZoomLevel: number;
    localization: import("../store/Localization").LocalizationStateType;
}, {
    setActivePages: (activePages: number[]) => {
        type: string;
        activePages: number[];
    };
    getComments: () => {
        type: string;
        inject: (options: import("redux-di-middleware").IInjectableActionCallbackParams<RootReducerType>) => Promise<void>;
    };
    setThumbnails: (isVisible: boolean) => {
        type: string;
        isVisible: boolean;
    };
    createComment: (comment: Pick<import("../models").Comment, "text" | "page" | "x" | "y">) => {
        type: string;
        inject: (options: import("redux-di-middleware").IInjectableActionCallbackParams<RootReducerType>) => Promise<void>;
    };
    setSelectedCommentId: typeof setSelectedCommentId;
    toggleIsCreateCommentActive: typeof toggleIsCreateCommentActive;
    toggleIsPlacingCommentMarker: typeof toggleIsPlacingCommentMarker;
}, DocumentLayoutOwnProps, {
    activePages: number[];
    zoomMode: import("../store").ZoomMode;
    customZoomLevel: number;
    showThumbnails: boolean;
    showComments: boolean;
    comments: import("../models").Comment[];
    pageCount: number;
    isCreateCommentActive: boolean;
    isPlacingCommentMarker: boolean;
    selectedCommentId: string;
    fitRelativeZoomLevel: number;
    localization: import("../store/Localization").LocalizationStateType;
}, RootReducerType>, "drawerSlideProps">>;
export { connectedComponent as DocumentViewerLayout };
//# sourceMappingURL=DocumentViewerLayout.d.ts.map