"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const Drawer_1 = tslib_1.__importDefault(require("@material-ui/core/Drawer"));
const Typography_1 = tslib_1.__importDefault(require("@material-ui/core/Typography"));
const React = require("react");
const react_redux_1 = require("react-redux");
const store_1 = require("../store");
const Comments_1 = require("../store/Comments");
const Comment_1 = tslib_1.__importDefault(require("./comment/Comment"));
const CreateComment_1 = require("./comment/CreateComment");
const _1 = require("./");
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
const mapStateToProps = (state) => {
    return {
        activePages: state.sensenetDocumentViewer.viewer.activePages,
        zoomMode: state.sensenetDocumentViewer.viewer.zoomMode,
        customZoomLevel: state.sensenetDocumentViewer.viewer.customZoomLevel,
        showThumbnails: state.sensenetDocumentViewer.viewer.showThumbnails,
        showComments: state.sensenetDocumentViewer.viewer.showComments,
        comments: state.comments.items,
        pageCount: state.sensenetDocumentViewer.documentState.document.pageCount,
        isCreateCommentActive: state.comments.isCreateCommentActive,
        isPlacingCommentMarker: state.comments.isPlacingCommentMarker,
        selectedCommentId: state.comments.selectedCommentId,
        fitRelativeZoomLevel: state.sensenetDocumentViewer.viewer.fitRelativeZoomLevel,
        localization: state.sensenetDocumentViewer.localization,
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
const mapDispatchToProps = {
    setActivePages: store_1.setActivePages,
    getComments: Comments_1.getComments,
    setThumbnails: store_1.setThumbnails,
    createComment: store_1.createComment,
    setSelectedCommentId: Comments_1.setSelectedCommentId,
    toggleIsCreateCommentActive: Comments_1.toggleIsCreateCommentActive,
    toggleIsPlacingCommentMarker: Comments_1.toggleIsPlacingCommentMarker,
};
const THUMBNAIL_PADDING = 16;
const THUMBNAIL_NAME = 'Thumbnail';
const PAGE_PADDING = 8;
const PAGE_NAME = 'Page';
/**
 * Component for the main DocumentViewer layout
 */
class DocumentViewerLayoutComponent extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            activePage: 1,
            thumbnaislVisibility: this.props.showThumbnails,
            createCommentValue: '',
        };
        this.commentsContainerRef = React.createRef();
        this.createComment = this.createComment.bind(this);
        this.handleKeyUp = this.handleKeyUp.bind(this);
        this.handleMarkerCreation = this.handleMarkerCreation.bind(this);
    }
    componentDidMount() {
        document.addEventListener('keyup', this.handleKeyUp);
    }
    componentWillUnmount() {
        document.removeEventListener('keyup', this.handleKeyUp);
    }
    /** scrolls the viewer to focus to the page with the provided index */
    scrollTo(index, smoothScroll = true) {
        this.setState(Object.assign({}, this.state, { activePage: index }), () => {
            this.scrollToImage({
                containerId: 'sn-document-viewer-pages',
                itemName: PAGE_NAME,
                padding: PAGE_PADDING,
                index,
                smoothScroll,
            });
            this.scrollToImage({
                containerId: 'sn-document-viewer-thumbnails',
                itemName: THUMBNAIL_NAME,
                padding: THUMBNAIL_PADDING,
                index,
                smoothScroll,
            });
            if (this.props.activePages[0] !== index) {
                this.props.setActivePages([index]);
                this.props.getComments();
            }
        });
    }
    scrollToImage({ containerId, index, itemName, padding, smoothScroll }) {
        const container = document.getElementById(containerId);
        const item = document.querySelector(`.${itemName}`);
        if (container && container.scrollTo && item) {
            container.scrollTo({
                top: (item.clientHeight + padding * 4) * (index - 1),
                behavior: smoothScroll ? 'smooth' : 'auto',
            });
        }
    }
    handleMarkerCreation(draftCommentMarker) {
        this.setState(Object.assign({}, this.state, { draftCommentMarker }));
    }
    createComment(text) {
        if (!this.state.draftCommentMarker || !this.state.activePage) {
            return;
        }
        this.props.createComment(Object.assign({ page: this.state.activePage, text }, this.state.draftCommentMarker));
        this.toggleIsPlacingCommentMarker(false);
    }
    toggleIsPlacingCommentMarker(isPlacingCommentMarker = !this.props.isPlacingCommentMarker) {
        this.props.toggleIsPlacingCommentMarker(isPlacingCommentMarker);
        this.setState(Object.assign({}, this.state, { draftCommentMarker: undefined }));
    }
    handleKeyUp(ev) {
        if (ev.key !== 'Escape') {
            return;
        }
        if (this.props.isPlacingCommentMarker) {
            return this.toggleIsPlacingCommentMarker(false);
        }
        if (this.props.isCreateCommentActive) {
            this.props.toggleIsCreateCommentActive(false);
        }
        this.props.setSelectedCommentId('');
        this.setState(Object.assign({}, this.state, { createCommentValue: '' }));
    }
    /** triggered when the component will receive props */
    componentWillReceiveProps(newProps) {
        if (this.props.activePages[0] !== newProps.activePages[0] ||
            this.props.fitRelativeZoomLevel !== newProps.fitRelativeZoomLevel) {
            this.scrollTo(newProps.activePages[0], this.props.fitRelativeZoomLevel === newProps.fitRelativeZoomLevel);
            this.toggleIsPlacingCommentMarker(false);
        }
        if (this.props.showThumbnails !== newProps.showThumbnails) {
            if (newProps.showThumbnails) {
                this.setState(Object.assign({}, this.state, { thumbnaislVisibility: true }));
                window.dispatchEvent(new Event('resize'));
            }
            else {
                setTimeout(() => {
                    this.setState(Object.assign({}, this.state, { thumbnaislVisibility: false }));
                    window.dispatchEvent(new Event('resize'));
                }, 200);
            }
        }
        if (this.props.selectedCommentId !== newProps.selectedCommentId) {
            const selectedCommentNode = document.getElementById(newProps.selectedCommentId);
            if (!selectedCommentNode) {
                return;
            }
            this.commentsContainerRef.current &&
                this.commentsContainerRef.current.scrollTo({
                    top: selectedCommentNode.offsetTop - selectedCommentNode.scrollHeight,
                    behavior: 'smooth',
                });
        }
    }
    /**
     * renders the component
     */
    render() {
        return (React.createElement("div", { style: {
                width: '100%',
                height: '100%',
                display: 'flex',
                flexDirection: 'column',
            } },
            this.props.children,
            React.createElement("div", { style: {
                    display: 'flex',
                    height: '100%',
                    width: '100%',
                    overflow: 'hidden',
                    zIndex: 0,
                    position: 'relative',
                } },
                React.createElement(Drawer_1.default, { variant: 'persistent', open: this.props.showThumbnails, anchor: "left", SlideProps: this.props.drawerSlideProps, PaperProps: {
                        style: {
                            position: 'relative',
                            width: this.state.thumbnaislVisibility ? '200px' : 0,
                            height: '100%',
                            overflow: 'hidden',
                        },
                    } },
                    React.createElement(_1.PageList, { showWidgets: false, style: { minWidth: 200, marginRight: '-16px', paddingRight: 0 }, id: "sn-document-viewer-thumbnails", zoomMode: "fit", fitRelativeZoomLevel: 0, zoomLevel: 1, onPageClick: (_ev, index) => this.scrollTo(index), elementName: THUMBNAIL_NAME, images: "thumbnail", tolerance: 0, padding: THUMBNAIL_PADDING, activePage: this.state.activePage })),
                React.createElement(_1.PageList, { handleMarkerCreation: this.handleMarkerCreation, showWidgets: true, id: "sn-document-viewer-pages", zoomMode: this.props.zoomMode, zoomLevel: this.props.customZoomLevel, fitRelativeZoomLevel: this.props.fitRelativeZoomLevel, onPageClick: (_ev, index) => this.scrollTo(index), elementName: PAGE_NAME, images: "preview", tolerance: 0, padding: PAGE_PADDING, activePage: this.state.activePage }),
                React.createElement(Drawer_1.default, { variant: 'persistent', open: this.props.showComments, anchor: "right", SlideProps: this.props.drawerSlideProps, PaperProps: {
                        style: {
                            position: 'relative',
                            width: this.props.showComments ? '340px' : 0,
                            height: '100%',
                            overflow: 'hidden',
                        },
                    } },
                    React.createElement(_1.CommentsContainer, { ref: this.commentsContainerRef },
                        React.createElement(Typography_1.default, { variant: "h4" }, this.props.localization.commentSideBarTitle),
                        React.createElement(CreateComment_1.CreateComment, { isActive: this.props.isCreateCommentActive, handleIsActive: isActive => this.props.toggleIsCreateCommentActive(isActive), draftCommentMarker: this.state.draftCommentMarker, handlePlaceMarkerClick: isPlacing => this.toggleIsPlacingCommentMarker(isPlacing), isPlacingMarker: this.props.isPlacingCommentMarker, localization: this.props.localization, createComment: this.createComment, inputValue: this.state.createCommentValue, handleInputValueChange: value => this.setState(Object.assign({}, this.state, { createCommentValue: value })) }),
                        this.props.comments.map(comment => (React.createElement(Comment_1.default, Object.assign({ key: comment.id }, comment)))))))));
    }
}
exports.DocumentViewerLayoutComponent = DocumentViewerLayoutComponent;
const connectedComponent = react_redux_1.connect(mapStateToProps, mapDispatchToProps)(DocumentViewerLayoutComponent);
exports.DocumentViewerLayout = connectedComponent;
//# sourceMappingURL=DocumentViewerLayout.js.map