import React = require('react');
import { DocumentData, DraftCommentMarker } from '../models';
import { componentType } from '../services';
import { RootReducerType, ZoomMode } from '../store';
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
declare const mapStateToProps: (state: RootReducerType, ownProps: {
    imageIndex: number;
}) => {
    documentData: DocumentData;
    version: string | undefined;
    page: import("../models").PreviewImageData;
    activePages: number[];
    showWatermark: boolean;
    pollInterval: number;
    isPlacingCommentMarker: boolean;
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
declare const mapDispatchToProps: {
    previewAvailable: (documentData: DocumentData, version?: string, page?: number) => {
        type: string;
        inject: (options: import("redux-di-middleware").IInjectableActionCallbackParams<RootReducerType>) => Promise<void>;
    };
};
/**
 * Defined the component's own properties
 */
export interface OwnProps {
    showWidgets: boolean;
    imageIndex: number;
    viewportHeight: number;
    viewportWidth: number;
    elementName: string;
    zoomMode: ZoomMode;
    zoomLevel: number;
    fitRelativeZoomLevel: number;
    onClick: (ev: React.MouseEvent<HTMLElement>) => any;
    margin: number;
    image: 'preview' | 'thumbnail';
    handleMarkerCreation?: (coordinates: DraftCommentMarker) => void;
}
/**
 * State model for the Page component
 */
export interface PageState {
    imgSrc: string;
    pageWidth: number;
    pageHeight: number;
    isActive: boolean;
    imageWidth: string;
    imageHeight: string;
    imageTransform: string;
    zoomRatio: number;
    isPolling: boolean;
    draftCommentMarker?: DraftCommentMarker;
}
/**
 * Represents a Page component that show the preview image on a Paper component
 * @extends {React.Component<componentType<typeof mapStateToProps, typeof mapDispatchToProps, OwnProps>, PageState>}
 */
export declare class PageComponent extends React.Component<componentType<typeof mapStateToProps, typeof mapDispatchToProps, OwnProps>, PageState> {
    constructor(props: PageComponent['props']);
    /** event before the component did unmount */
    componentWillUnmount(): void;
    private stopPolling;
    private handleMarkerPlacement;
    private pollPreview?;
    /**
     * Returns a derived state from the specified props
     * @param props The props for state creation
     */
    static getDerivedStateFromProps(props: PageComponent['props'], state: PageState): PageState;
    /**
     * renders the component
     */
    render(): JSX.Element;
}
declare const connectedComponent: import("react-redux").ConnectedComponentClass<typeof PageComponent, Pick<componentType<(state: RootReducerType, ownProps: {
    imageIndex: number;
}) => {
    documentData: DocumentData;
    version: string | undefined;
    page: import("../models").PreviewImageData;
    activePages: number[];
    showWatermark: boolean;
    pollInterval: number;
    isPlacingCommentMarker: boolean;
}, {
    previewAvailable: (documentData: DocumentData, version?: string, page?: number) => {
        type: string;
        inject: (options: import("redux-di-middleware").IInjectableActionCallbackParams<RootReducerType>) => Promise<void>;
    };
}, OwnProps, {
    documentData: DocumentData;
    version: string | undefined;
    page: import("../models").PreviewImageData;
    activePages: number[];
    showWatermark: boolean;
    pollInterval: number;
    isPlacingCommentMarker: boolean;
}, RootReducerType>, "image" | "onClick" | "viewportWidth" | "viewportHeight" | "elementName" | "zoomMode" | "zoomLevel" | "fitRelativeZoomLevel" | "showWidgets" | "handleMarkerCreation" | "imageIndex" | "margin"> & {
    imageIndex: number;
}>;
export { connectedComponent as Page };
//# sourceMappingURL=Page.d.ts.map