"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const Grid_1 = tslib_1.__importDefault(require("@material-ui/core/Grid"));
const react_1 = tslib_1.__importDefault(require("react"));
const react_redux_1 = require("react-redux");
const client_utils_1 = require("@sensenet/client-utils");
const services_1 = require("../services");
const _1 = require("./");
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
const mapStateToProps = (state) => {
    return {
        pages: state.sensenetDocumentViewer.previewImages.AvailableImages || [],
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
const mapDispatchToProps = {};
/**
 * Represents list of pages in a Grid component
 * @extends {React.Component<componentType<typeof mapStateToProps, typeof mapDispatchToProps, PageListProps>, PageListState>}
 */
class PageListComponent extends react_1.default.Component {
    constructor() {
        super(...arguments);
        /** the component state */
        this.state = {
            marginTop: 0,
            marginBottom: 0,
            scrollState: 0,
            pagesToSkip: 0,
            viewportWidth: 110,
            viewportHeight: 110,
            pagesToTake: 32,
            visiblePages: this.props.pages.slice(0, 3),
        };
        this.canUpdate = false;
    }
    /** event that will be triggered before mounting the component */
    componentWillMount() {
        this.onResize = client_utils_1.debounce(() => this.setupViewPort(), 50).bind(this);
        addEventListener('resize', this.onResize);
        this.onResize();
        this.canUpdate = true;
    }
    /** event that will be triggered after mounting the component */
    componentDidMount() {
        this.setupViewPort();
        this.onScroll = client_utils_1.debounce(() => this.setupVisiblePages(this.props), 10).bind(this);
        this.viewPort && this.viewPort.addEventListener('scroll', this.onScroll);
        this.onScroll();
    }
    /** event that will be triggered before unmounting the component */
    componentWillUnmount() {
        removeEventListener('resize', this.onResize);
        this.viewPort && this.viewPort.removeEventListener('scroll', this.onScroll);
        this.canUpdate = false;
    }
    /** triggered when the component will receive props */
    componentWillReceiveProps(newProps) {
        this.setupVisiblePages(newProps, newProps.activePage !== this.props.activePage ? newProps.activePage : undefined);
    }
    setupVisiblePages(props, pageNo) {
        if (!props.pages.length || !this.canUpdate) {
            return;
        }
        let defaultWidth;
        let defaultHeight;
        const pages = props.pages.map(p => {
            if ((p && !defaultWidth) || !defaultHeight) {
                ;
                [defaultWidth, defaultHeight] = [p.Width, p.Height];
            }
            if (!p.Width || !p.Height) {
                ;
                [p.Width, p.Height] = [defaultWidth, defaultHeight];
            }
            const relativeSize = services_1.ImageUtil.getImageSize({
                width: this.state.viewportWidth,
                height: this.state.viewportHeight,
            }, {
                width: p.Width,
                height: p.Height,
                rotation: (p.Attributes && p.Attributes.degree) || 0,
            }, props.zoomMode, props.zoomLevel, props.fitRelativeZoomLevel);
            return Object.assign({}, p, { Width: relativeSize.width, Height: relativeSize.height });
        });
        const scrollState = (this.viewPort && this.viewPort.scrollTop) || 0;
        let marginTop = 0;
        let pagesToSkip = 0;
        while (pageNo !== undefined
            ? pagesToSkip < pageNo - 1
            : pages[pagesToSkip] && marginTop + pages[pagesToSkip].Height + props.tolerance < scrollState) {
            marginTop += pages[pagesToSkip].Height + props.padding * 2;
            pagesToSkip++;
        }
        let pagesToTake = 1;
        let pagesHeight = 0;
        while (pages[pagesToSkip + pagesToTake] && pagesHeight < this.state.viewportHeight + props.tolerance) {
            pagesHeight += pages[pagesToSkip + pagesToTake].Height + props.padding * 2;
            pagesToTake++;
        }
        let marginBottom = 0;
        for (let i = pagesToSkip + pagesToTake - 1; i < pages.length - 1; i++) {
            marginBottom += pages[i].Height + props.padding * 2;
        }
        if (pagesToSkip !== this.state.pagesToSkip || pagesToTake !== this.state.pagesToTake) {
            this.setState(Object.assign({}, this.state, { marginTop,
                marginBottom,
                pagesToSkip,
                pagesToTake,
                scrollState, visiblePages: pages.slice(pagesToSkip, pagesToSkip + pagesToTake) }));
            // this.forceUpdate()
        }
    }
    setupViewPort() {
        if (!this.viewPort) {
            this.viewPort = document.querySelector(`#${this.props.id}`) || undefined;
        }
        if (this.canUpdate && this.viewPort) {
            const newHeight = this.viewPort.clientHeight - this.props.padding * 2;
            const newWidth = this.viewPort.clientWidth - this.props.padding * 2;
            if (!this.state || newHeight !== this.state.viewportHeight || newWidth !== this.state.viewportWidth) {
                this.setState(Object.assign({}, this.state, { visiblePages: this.state.visiblePages, viewportHeight: newHeight, viewportWidth: newWidth }));
                this.forceUpdate();
            }
        }
    }
    /**
     * renders the component
     */
    render() {
        return (react_1.default.createElement(Grid_1.default, { item: true, style: Object.assign({}, this.props.style, { flexGrow: 1, flexShrink: 1, overflow: 'auto', height: '100%' }), id: this.props.id },
            react_1.default.createElement("div", { style: {
                    display: 'flex',
                    flexDirection: 'column',
                    justifyContent: 'center',
                    alignItems: 'center',
                    paddingTop: this.state.marginTop || 0,
                    paddingBottom: this.state.marginBottom || 0,
                } }, this.state.visiblePages.map(value => (react_1.default.createElement(_1.Page, { handleMarkerCreation: this.props.handleMarkerCreation, showWidgets: this.props.showWidgets, viewportWidth: this.state.viewportWidth, viewportHeight: this.state.viewportHeight, key: value.Index, imageIndex: value.Index, onClick: ev => this.props.onPageClick(ev, value.Index), zoomMode: this.props.zoomMode, zoomLevel: this.props.zoomLevel, fitRelativeZoomLevel: this.props.fitRelativeZoomLevel, elementName: this.props.elementName, image: this.props.images, margin: this.props.padding }))))));
    }
}
exports.PageListComponent = PageListComponent;
const connectedComponent = react_redux_1.connect(mapStateToProps, mapDispatchToProps)(PageListComponent);
exports.PageList = connectedComponent;
//# sourceMappingURL=PageList.js.map