"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const ClickAwayListener_1 = tslib_1.__importDefault(require("@material-ui/core/ClickAwayListener"));
const TextField_1 = tslib_1.__importDefault(require("@material-ui/core/TextField"));
const Typography_1 = tslib_1.__importDefault(require("@material-ui/core/Typography"));
const react_1 = tslib_1.__importStar(require("react"));
const react_redux_1 = require("react-redux");
const client_utils_1 = require("@sensenet/client-utils");
const store_1 = require("../../store");
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
exports.mapStateToProps = (state) => {
    return {
        documentName: state.sensenetDocumentViewer.documentState.document.documentName,
        activePages: state.sensenetDocumentViewer.viewer.activePages,
        pageCount: state.sensenetDocumentViewer.documentState.document.pageCount,
        gotoPage: state.sensenetDocumentViewer.localization.gotoPage,
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
exports.mapDispatchToProps = {
    setActivePages: store_1.setActivePages,
};
/**
 * Document widget component for paging
 */
exports.DocumentTitlePagerComponent = props => {
    const [isFocused, setIsFocused] = react_1.useState(false);
    const setPage = client_utils_1.debounce((index) => {
        props.setActivePages([index]);
    }, 200);
    const gotoPage = (page) => {
        let pageInt = typeof page === 'string' ? parseInt(page, 10) : page;
        if (!isNaN(pageInt)) {
            pageInt = Math.max(pageInt, 1);
            pageInt = Math.min(pageInt, props.pageCount);
            setPage(pageInt);
        }
    };
    return (react_1.default.createElement(ClickAwayListener_1.default, { onClickAway: () => setIsFocused(false) },
        react_1.default.createElement(Typography_1.default, { onClick: () => setIsFocused(true), variant: "h6", color: "inherit", style: { cursor: 'pointer', display: 'flex', alignItems: 'center', overflow: 'hidden', margin: '0 2.5em' }, title: props.documentName },
            react_1.default.createElement("div", { style: { whiteSpace: 'nowrap', overflow: 'hidden', textOverflow: 'ellipsis' } },
                props.documentName,
                "\u00A0"),
            isFocused ? (react_1.default.createElement("form", { onSubmit: event => event.preventDefault() },
                react_1.default.createElement(TextField_1.default, { style: { flexShrink: 0 }, title: props.gotoPage, value: props.activePages[0], onChange: ev => gotoPage(ev.currentTarget.value), type: "number", required: true, InputLabelProps: {
                        shrink: true,
                    }, inputProps: {
                        min: 1,
                        max: props.pageCount,
                        style: { textAlign: 'center' },
                    }, margin: "dense" }))) : (react_1.default.createElement("div", { style: { flexShrink: 0 } },
                props.activePages[0],
                " / ",
                props.pageCount)))));
};
const connectedComponent = react_redux_1.connect(exports.mapStateToProps, exports.mapDispatchToProps)(exports.DocumentTitlePagerComponent);
exports.DocumentTitlePager = connectedComponent;
//# sourceMappingURL=DocumentTitlePager.js.map