import React from 'react';
import { RootReducerType } from '../../store';
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
export declare const mapStateToProps: (state: RootReducerType) => {
    activePages: number[];
    pageCount: number;
    firstPage: string;
    previousPage: string;
    gotoPage: string;
    nextPage: string;
    lastPage: string;
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
export declare const mapDispatchToProps: {
    setActivePages: (activePages: number[]) => {
        type: string;
        activePages: number[];
    };
};
/**
 * Defines the own props for the PagerState component
 */
export interface PagerState {
    currentPage: number;
    lastPage: number;
}
/**
 * Document widget component for paging
 */
export declare class PagerComponent extends React.Component<ReturnType<typeof mapStateToProps> & typeof mapDispatchToProps, PagerState> {
    /** the component state */
    state: {
        currentPage: number;
        lastPage: number;
    };
    private setPage;
    /** creates a derived state from props */
    static getDerivedStateFromProps(nextProps: PagerComponent['props'], lastState: Partial<PagerComponent['state']>): {
        currentPage: number;
        lastPage: number;
    };
    private gotoPage;
    /**
     * renders the component
     */
    render(): JSX.Element;
}
declare const connectedComponent: import("react-redux").ConnectedComponentClass<typeof PagerComponent, Pick<{
    activePages: number[];
    pageCount: number;
    firstPage: string;
    previousPage: string;
    gotoPage: string;
    nextPage: string;
    lastPage: string;
} & {
    setActivePages: (activePages: number[]) => {
        type: string;
        activePages: number[];
    };
}, never>>;
export { connectedComponent as PagerWidget };
//# sourceMappingURL=Pager.d.ts.map