"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const IconButton_1 = tslib_1.__importDefault(require("@material-ui/core/IconButton"));
const RotateLeft_1 = tslib_1.__importDefault(require("@material-ui/icons/RotateLeft"));
const RotateRight_1 = tslib_1.__importDefault(require("@material-ui/icons/RotateRight"));
const react_1 = tslib_1.__importDefault(require("react"));
const react_redux_1 = require("react-redux");
const store_1 = require("../../store");
/**
 * The amount of rotation in degrees
 */
exports.ROTATION_AMOUNT = 90;
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
exports.mapStateToProps = (state) => {
    return {
        rotateLeft: state.sensenetDocumentViewer.localization.rotatePageLeft,
        rotateRight: state.sensenetDocumentViewer.localization.rotatePageRight,
    };
};
/**
 * maps state actions from the store to component props
 */
exports.mapDispatchToProps = {
    rotateImages: store_1.rotateImages,
    rotateShapesForPages: store_1.rotateShapesForPages,
};
/**
 * Page widget component for rotating a specified page
 */
class RotatePageComponent extends react_1.default.Component {
    rotatePageLeft() {
        this.props.rotateImages([this.props.page.Index], -exports.ROTATION_AMOUNT);
        this.props.rotateShapesForPages([{ index: this.props.page.Index, size: { width: this.props.page.Width, height: this.props.page.Height } }], -exports.ROTATION_AMOUNT);
    }
    rotatePageRight() {
        this.props.rotateImages([this.props.page.Index], exports.ROTATION_AMOUNT);
        this.props.rotateShapesForPages([{ index: this.props.page.Index, size: { width: this.props.page.Width, height: this.props.page.Height } }], exports.ROTATION_AMOUNT);
    }
    /**
     * renders the component
     */
    render() {
        return (react_1.default.createElement("div", { style: {
                position: 'absolute',
                zIndex: 1,
                top: 0,
                right: 0,
                filter: 'drop-shadow(0 0 3px white) drop-shadow(0 0 5px white) drop-shadow(0 0 9px white)',
            } },
            react_1.default.createElement(IconButton_1.default, { title: this.props.rotateLeft },
                react_1.default.createElement(RotateLeft_1.default, { onClick: () => this.rotatePageLeft() })),
            react_1.default.createElement(IconButton_1.default, { title: this.props.rotateRight },
                react_1.default.createElement(RotateRight_1.default, { onClick: () => this.rotatePageRight() }))));
    }
}
exports.RotatePageComponent = RotatePageComponent;
const connectedComponent = react_redux_1.connect(exports.mapStateToProps, exports.mapDispatchToProps)(RotatePageComponent);
exports.RotatePageWidget = connectedComponent;
//# sourceMappingURL=RotatePage.js.map