import React from 'react';
import { Annotation, DraftCommentMarker, PreviewImageData, Shape, Shapes } from '../../models';
import { componentType, Dimensions } from '../../services';
import { RootReducerType } from '../../store';
import { setSelectedCommentId } from '../../store/Comments';
/**
 * Defined the component's own properties
 */
export interface OwnProps {
    viewPort: Dimensions;
    page: PreviewImageData;
    zoomRatio: number;
    draftCommentMarker?: DraftCommentMarker;
}
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
export declare const mapStateToProps: (state: RootReducerType, ownProps: OwnProps) => {
    showShapes: boolean;
    showRedactions: boolean;
    showComments: boolean;
    canHideRedactions: boolean;
    redactions: Shape[];
    highlights: Shape[];
    annotations: Annotation[];
    commentMarkers: {
        x: number;
        y: number;
        id: string;
    }[];
    selectedCommentId: string;
    canEdit: boolean;
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
export declare const mapDispatchToProps: {
    updateShapeData: <K extends "redactions" | "highlights" | "annotations">(shapeType: K, shapeGuid: string, shapeData: Shapes[K][0]) => {
        type: string;
        shapeType: K;
        shapeGuid: string;
        shapeData: Shapes[K][0];
    };
    setSelectedCommentId: typeof setSelectedCommentId;
};
/**
 * Page widget component for displaying shapes on a page
 */
export declare class ShapesComponent extends React.Component<componentType<typeof mapStateToProps, typeof mapDispatchToProps, OwnProps>> {
    private onDrop;
    /**
     * renders the component
     */
    render(): JSX.Element;
}
declare const connectedComponent: import("react-redux").ConnectedComponentClass<typeof ShapesComponent, Pick<componentType<(state: RootReducerType, ownProps: OwnProps) => {
    showShapes: boolean;
    showRedactions: boolean;
    showComments: boolean;
    canHideRedactions: boolean;
    redactions: Shape[];
    highlights: Shape[];
    annotations: Annotation[];
    commentMarkers: {
        x: number;
        y: number;
        id: string;
    }[];
    selectedCommentId: string;
    canEdit: boolean;
}, {
    updateShapeData: <K extends "redactions" | "highlights" | "annotations">(shapeType: K, shapeGuid: string, shapeData: Shapes[K][0]) => {
        type: string;
        shapeType: K;
        shapeGuid: string;
        shapeData: Shapes[K][0];
    };
    setSelectedCommentId: typeof setSelectedCommentId;
}, OwnProps, {
    showShapes: boolean;
    showRedactions: boolean;
    showComments: boolean;
    canHideRedactions: boolean;
    redactions: Shape[];
    highlights: Shape[];
    annotations: Annotation[];
    commentMarkers: {
        x: number;
        y: number;
        id: string;
    }[];
    selectedCommentId: string;
    canEdit: boolean;
}, RootReducerType>, "page" | "zoomRatio" | "draftCommentMarker" | "viewPort"> & OwnProps>;
export { connectedComponent as ShapesWidget };
//# sourceMappingURL=Shapes.d.ts.map