"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const react_1 = tslib_1.__importDefault(require("react"));
const react_redux_1 = require("react-redux");
const store_1 = require("../../store");
const Comments_1 = require("../../store/Comments");
const Shape_1 = require("./Shape");
const style_1 = require("./style");
/**
 * maps state fields from the store to component props
 * @param state the redux state
 */
exports.mapStateToProps = (state, ownProps) => {
    const commentMarkers = state.comments.items
        .filter(comment => comment.page === ownProps.page.Index)
        .map(comment => {
        return { x: comment.x, y: comment.y, id: comment.id };
    });
    ownProps.draftCommentMarker && commentMarkers.push(ownProps.draftCommentMarker);
    return {
        showShapes: state.sensenetDocumentViewer.viewer.showShapes,
        showRedactions: state.sensenetDocumentViewer.viewer.showRedaction,
        showComments: state.sensenetDocumentViewer.viewer.showComments,
        canHideRedactions: state.sensenetDocumentViewer.documentState.canHideRedaction,
        redactions: state.sensenetDocumentViewer.documentState.document.shapes.redactions.filter(r => r.imageIndex === ownProps.page.Index),
        highlights: state.sensenetDocumentViewer.documentState.document.shapes.highlights.filter(r => r.imageIndex === ownProps.page.Index),
        annotations: state.sensenetDocumentViewer.documentState.document.shapes.annotations.filter(r => r.imageIndex === ownProps.page.Index),
        commentMarkers,
        selectedCommentId: state.comments.selectedCommentId,
        canEdit: state.sensenetDocumentViewer.documentState.canEdit,
    };
};
/**
 * maps state actions from the store to component props
 * @param state the redux state
 */
exports.mapDispatchToProps = {
    updateShapeData: store_1.updateShapeData,
    setSelectedCommentId: Comments_1.setSelectedCommentId,
};
/**
 * Page widget component for displaying shapes on a page
 */
class ShapesComponent extends react_1.default.Component {
    onDrop(ev, page) {
        if (this.props.canEdit) {
            ev.preventDefault();
            const shapeData = JSON.parse(ev.dataTransfer.getData('shape'));
            const boundingBox = ev.currentTarget.getBoundingClientRect();
            this.props.updateShapeData(shapeData.type, shapeData.shape.guid, Object.assign({}, shapeData.shape, { imageIndex: page.Index, x: (ev.clientX - boundingBox.left - shapeData.offset.width) * (1 / this.props.zoomRatio), y: (ev.clientY - boundingBox.top - shapeData.offset.height) * (1 / this.props.zoomRatio) }));
        }
    }
    /**
     * renders the component
     */
    render() {
        return (react_1.default.createElement(style_1.ShapesContainer, null,
            this.props.showComments &&
                this.props.commentMarkers.map(marker => (react_1.default.createElement(style_1.CommentMarker, { onClick: () => this.props.setSelectedCommentId(marker.id), isSelected: marker.id === this.props.selectedCommentId, zoomRatio: this.props.zoomRatio, marker: marker, key: marker.id }))),
            react_1.default.createElement("div", { onDrop: ev => this.onDrop(ev, this.props.page), onDragOver: ev => ev.preventDefault() },
                this.props.canHideRedactions &&
                    this.props.showRedactions &&
                    this.props.redactions.map((redaction, index) => {
                        return (react_1.default.createElement(Shape_1.ShapeRedaction, { shapeType: "redactions", shape: redaction, canEdit: this.props.canEdit, zoomRatio: this.props.zoomRatio, key: index }));
                    }),
                this.props.showShapes &&
                    this.props.annotations.map((annotation, index) => {
                        return (react_1.default.createElement(Shape_1.ShapeAnnotation, { shapeType: "annotations", shape: annotation, canEdit: this.props.canEdit, zoomRatio: this.props.zoomRatio, key: index }));
                    }),
                this.props.showShapes &&
                    this.props.highlights.map((highlight, index) => {
                        return (react_1.default.createElement(Shape_1.ShapeHighlight, { shapeType: "highlights", shape: highlight, canEdit: this.props.canEdit, zoomRatio: this.props.zoomRatio, key: index }));
                    }))));
    }
}
exports.ShapesComponent = ShapesComponent;
const connectedComponent = react_redux_1.connect(exports.mapStateToProps, exports.mapDispatchToProps)(ShapesComponent);
exports.ShapesWidget = connectedComponent;
//# sourceMappingURL=Shapes.js.map