"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const models_1 = require("../models");
const Viewer_1 = require("./Viewer");
exports.SET_SELECTED_COMMENT_ID = 'SET_SELECTED_COMMENT_ID';
exports.GET_COMMENTS_SUCCESS = 'GET_COMMENTS_SUCCESS';
exports.GET_COMMENTS_REQUEST = 'GET_COMMENTS_REQUEST';
exports.CREATE_COMMENT_REQUEST = 'CREATE_COMMENT_REQUEST';
exports.CREATE_COMMENT_SUCCESS = 'CREATE_COMMENTS_SUCCESS';
exports.DELETE_COMMENT_SUCCESS = 'DELETE_COMMENTS_SUCCESS';
exports.DELETE_COMMENT_REQUEST = 'DELETE_COMMENT_REQUEST';
exports.TOGGLE_IS_CREATE_COMMENT_ACTIVE = 'TOGGLE_IS_CREATE_COMMENT_ACTIVE';
exports.TOGGLE_IS_PLACING_COMMENT_MARKER = 'TOGGLE_IS_PLACING_COMMENT_MARKER';
exports.getCommentsSuccess = (comments) => ({
    type: exports.GET_COMMENTS_SUCCESS,
    comments,
});
exports.createCommentSuccess = (comment) => ({
    type: exports.CREATE_COMMENT_SUCCESS,
    comment,
});
exports.deleteCommentSuccess = (id) => ({
    type: exports.DELETE_COMMENT_SUCCESS,
    id,
});
exports.getComments = () => ({
    type: exports.GET_COMMENTS_REQUEST,
    inject: (options) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const api = options.getInjectable(models_1.DocumentViewerSettings);
        const comments = yield api.commentActions.getPreviewComments(options.getState().sensenetDocumentViewer.documentState.document, options.getState().sensenetDocumentViewer.viewer.activePages[0]);
        options.dispatch(exports.getCommentsSuccess(comments));
        if (comments.length) {
            options.dispatch(Viewer_1.showComments(true));
        }
    }),
});
exports.createComment = (comment) => ({
    type: exports.CREATE_COMMENT_REQUEST,
    inject: (options) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const api = options.getInjectable(models_1.DocumentViewerSettings);
        const result = yield api.commentActions.addPreviewComment(options.getState().sensenetDocumentViewer.documentState.document, comment);
        options.dispatch(exports.createCommentSuccess(result));
    }),
});
exports.deleteComment = (id) => ({
    type: exports.DELETE_COMMENT_REQUEST,
    inject: (options) => tslib_1.__awaiter(this, void 0, void 0, function* () {
        const api = options.getInjectable(models_1.DocumentViewerSettings);
        const result = yield api.commentActions.deletePreviewComment(options.getState().sensenetDocumentViewer.documentState.document, id);
        result.modified && options.dispatch(exports.deleteCommentSuccess(id));
    }),
});
/**
 * Set selected comment id action
 */
function setSelectedCommentId(id) {
    return {
        type: exports.SET_SELECTED_COMMENT_ID,
        id,
    };
}
exports.setSelectedCommentId = setSelectedCommentId;
/**
 * Toggle isCreateCommentActive action
 */
function toggleIsCreateCommentActive(isActive) {
    return {
        type: exports.TOGGLE_IS_CREATE_COMMENT_ACTIVE,
        isActive,
    };
}
exports.toggleIsCreateCommentActive = toggleIsCreateCommentActive;
/**
 * Toggle isPlacingCommentMarker action
 */
function toggleIsPlacingCommentMarker(isPlacing) {
    return {
        type: exports.TOGGLE_IS_PLACING_COMMENT_MARKER,
        isPlacing,
    };
}
exports.toggleIsPlacingCommentMarker = toggleIsPlacingCommentMarker;
exports.commentsDefaultState = {
    selectedCommentId: '',
    items: [],
    isCreateCommentActive: false,
    isPlacingCommentMarker: false,
};
/**
 * Reducer method for the comments state
 */
exports.commentsStateReducer = (state = exports.commentsDefaultState, action) => {
    switch (action.type) {
        case exports.SET_SELECTED_COMMENT_ID:
            return Object.assign({}, state, { selectedCommentId: action.id });
        case exports.TOGGLE_IS_CREATE_COMMENT_ACTIVE: {
            return Object.assign({}, state, { isCreateCommentActive: action.isActive });
        }
        case exports.TOGGLE_IS_PLACING_COMMENT_MARKER: {
            return Object.assign({}, state, { isPlacingCommentMarker: action.isPlacing });
        }
        case exports.GET_COMMENTS_SUCCESS:
            return Object.assign({}, state, { items: action.comments });
        case exports.CREATE_COMMENT_SUCCESS:
            return Object.assign({}, state, { items: [...state.items, action.comment] });
        case exports.DELETE_COMMENT_SUCCESS:
            return Object.assign({}, state, { items: state.items.filter(comment => comment.id !== action.id) });
        default:
            return state;
    }
};
//# sourceMappingURL=Comments.js.map