"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Action to set the active page(s)
 * @param activePages
 */
exports.setActivePages = (activePages) => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_PAGE',
    activePages,
});
/**
 * Action to set the zoom mode
 * @param zoomMode
 */
exports.setZoomMode = (zoomMode) => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_ZOOM_MODE',
    zoomMode,
});
/**
 * Action to set the zoom level to a custom value
 * @param customZoomLevel
 * @param defaultModeOnZero
 */
exports.setCustomZoomLevel = (customZoomLevel, defaultModeOnZero = 'fit') => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_CUSTOM_ZOOM_LEVEL',
    customZoomLevel,
    defaultModeOnZero,
});
/**
 * Action to set the zoom level to a custom value
 * @param customZoomLevel
 */
exports.setFitRelativeZoomLevel = (fitRelativeZoomLevel) => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_FIT_RELATIVE_ZOOM_LEVEL',
    fitRelativeZoomLevel,
});
/**
 * Action to set the visibility of the watermark
 * @param isVisible
 */
exports.setWatermark = (isVisible) => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_WATERMARK',
    isVisible,
});
/**
 * Action to set the visibility of the redactions
 * @param isVisible
 */
exports.setRedaction = (isVisible) => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_REDACTION',
    isVisible,
});
/**
 * Action to set the visibility of the shapes
 * @param isVisible
 */
exports.setShapes = (isVisible) => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_SHAPES',
    isVisible,
});
/**
 * Action to set the visibility of the thumbnails
 * @param isVisible
 */
exports.setThumbnails = (isVisible) => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_THUMBNAILS',
    isVisible,
});
/**
 * Action to set the visibility of the comments
 */
exports.showComments = (isVisible) => ({
    type: 'SN_DOCVIEWER_DOCUMENT_VIEWER_SHOW_COMMENTS',
    isVisible,
});
/**
 * Reducer for the Viewer state
 * @param state the current state
 * @param action the dispatched action
 */
exports.viewerStateReducer = (state = {
    activePages: [1],
    zoomMode: 'fit',
    customZoomLevel: 3,
    showWatermark: false,
    showRedaction: true,
    showShapes: true,
    showThumbnails: false,
    fitRelativeZoomLevel: 0,
    showComments: false,
}, action) => {
    switch (action.type) {
        case 'SN_DOCVIEWER_DOCUMENT_RESET_DOCUMENT':
            return Object.assign({}, state, { activePages: [1] });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_PAGE':
            return Object.assign({}, state, { activePages: [...action.activePages] });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_ZOOM_MODE':
            return Object.assign({}, state, { zoomMode: action.zoomMode, customZoomLevel: 0 });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_CUSTOM_ZOOM_LEVEL':
            return Object.assign({}, state, { zoomMode: !action.customZoomLevel ? action.defaultModeOnZero : 'custom', customZoomLevel: action.customZoomLevel });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_WATERMARK':
            return Object.assign({}, state, { showWatermark: action.isVisible });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_REDACTION':
            return Object.assign({}, state, { showRedaction: action.isVisible });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_SHAPES':
            return Object.assign({}, state, { showShapes: action.isVisible });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SHOW_COMMENTS':
            return Object.assign({}, state, { showComments: action.isVisible });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_THUMBNAILS':
            return Object.assign({}, state, { showThumbnails: action.isVisible });
        case 'SN_DOCVIEWER_DOCUMENT_VIEWER_SET_FIT_RELATIVE_ZOOM_LEVEL':
            return Object.assign({}, state, { fitRelativeZoomLevel: action.fitRelativeZoomLevel });
        default:
            return state;
    }
};
//# sourceMappingURL=Viewer.js.map